@@ -37,13 +37,13 @@ class BaseAggregationManager(object):
         integration_data = get_integration_info(
             self.platform_id, self._data['integration_id'], self.access_token
         )
-        calc_step = integration_data['calculation']
+        calc_step = integration_data.get('calculation', {})
         cost = calc_step['cost'] if calc_step else None
         if cost:
             return cost.replace('{{', '').replace('}}', '')
         return ''
 
-    def _calculate(calc_step: str, cost: dict, field: str):
+    def _calculate(self, calc_step: str, cost: dict, field: str):
         if calc_step:
             calc_value = eval(calc_step.replace(field, str(cost[f'{field}__sum'])))
             return {'cost__sum': round(calc_value, 2)}
