@@ -13,7 +13,7 @@ __all__ = (
 
 class GeneratorListSerializer(ListSerializer):
     def to_representation(self, data):
-        iterable = data if isinstance(data, Manager) else data
+        iterable = data.iterator() if isinstance(data, Manager) else data
         for item in iterable:
             yield self.child.to_representation(item)
 
