@@ -112,10 +112,10 @@ def write_file(
     with open(filename, 'w') as f:
         if not fieldnames:
             fieldnames = list(data[0].keys())
-        writer = csv.DictWriter(f, delimiter=delimiter, fieldnames=fieldnames)
-        writer.writeheader()
+        writer = csv.writer(f, delimiter=delimiter)
+        writer.writerow(fieldnames)
         for row in data:
-            writer.writerow(row)
+            writer.writerow(row.values())
     return filename
 
 
@@ -362,10 +362,10 @@ def decode(enc: str, secret: Optional[str] = None):
 def write_ram_file(
     f: StringIO, data: Generator, fieldnames: list, delimiter='\t'
 ) -> StringIO:
-    writer = csv.DictWriter(f, delimiter=delimiter, fieldnames=fieldnames)
-    writer.writeheader()
+    writer = csv.writer(f, delimiter=delimiter)
+    writer.writerow(fieldnames)
     for row in data:
-        writer.writerow(row)
+        writer.writerow(row.values())
     return f
 
 
