@@ -208,3 +208,20 @@ class BaseStatTSVAPIView(CredentialMixin, APIView):
             'values': values,
         }
 
+
+class BaseAggregationComparisonAPIView(CredentialMixin, APIView):
+    check_credential = False
+    aggregation_manager = None
+
+    def get_aggregation_manager(self):
+        if self.aggregation_manager:
+            return self.aggregation_manager
+        raise NotImplementedError('aggregation_manager must be implemented.')
+
+    def post(self, request):
+        access_token = request.META['HTTP_AUTHORIZATION'].split(' ')[1]
+        if 'data' not in request.data:
+            raise PermissionDenied('miss data or executetoken')
+        agg_manager = self.get_aggregation_manager()(request.data, access_token)
+        result = agg_manager.aggegation_data()
+        return Response({'result': result})
